@@ -12,8 +12,7 @@ use proc_macro2::Span;
 use quote::quote;
 use syn::parse;
 use syn::parse::{Parse, ParseStream};
-use syn::token::Comma;
-use syn::{parse_macro_input, Ident, LitStr, Token};
+use syn::{parse_macro_input, Ident, LitStr};
 
 use log::warn;
 
@@ -22,32 +21,32 @@ use time::{format_description::FormatItem, macros::format_description, OffsetDat
 const DATE_FORMAT: &[FormatItem<'_>] = format_description!("[year]-[month]-[day]");
 
 struct TestamentOptions {
+    crate_: Ident,
     name: Ident,
 }
 
 impl Parse for TestamentOptions {
     fn parse(input: ParseStream) -> parse::Result<Self> {
-        let name: Ident = input.parse()?;
-        Ok(TestamentOptions { name })
+        Ok(TestamentOptions {
+            crate_: input.parse()?,
+            name: input.parse()?,
+        })
     }
 }
 
 struct StaticTestamentOptions {
+    crate_: Ident,
     name: Ident,
-    trusted: Option<String>,
+    trusted: Option<LitStr>,
 }
 
 impl Parse for StaticTestamentOptions {
     fn parse(input: ParseStream) -> parse::Result<Self> {
-        let name: Ident = input.parse()?;
-        let trusted = if input.peek(Token![,]) {
-            input.parse::<Comma>()?;
-            let t: LitStr = input.parse()?;
-            Some(t.value())
-        } else {
-            None
-        };
-        Ok(StaticTestamentOptions { name, trusted })
+        Ok(StaticTestamentOptions {
+            crate_: input.parse()?,
+            name: input.parse()?,
+            trusted: input.parse()?,
+        })
     }
 }
 
@@ -309,39 +308,9 @@ impl GitInformation {
     }
 }
 
-// Clippy thinks our fn main() is needless, but it is needed because otherwise
-// we cannot have the invocation of the procedural macro (yet)
-#[allow(clippy::needless_doctest_main)]
-/// Generate a testament for the working tree.
-///
-/// This macro declares a static data structure which represents a testament
-/// to the state of a git repository at the point that a crate was built.
-///
-/// The intention is that the macro should be used at the top level of a binary
-/// crate to provide information about the state of the codebase that the output
-/// program was built from.  This includes a number of things such as the commit
-/// SHA, any related tag, how many commits since the tag, the date of the commit,
-/// and if there are any "dirty" parts to the working tree such as modified files,
-/// uncommitted files, etc.
-///
-/// ```
-/// // Bring the procedural macro into scope
-/// use git_testament::git_testament;
-///
-/// // Declare a testament, it'll end up as a static, so give it a capital
-/// // letters name or it'll result in a warning.
-/// git_testament!(TESTAMENT);
-/// # fn main() {
-///
-/// // ... later, you can display the testament.
-/// println!("app version {TESTAMENT}");
-/// # }
-/// ```
-///
-/// See [`git_testament::GitTestament`] for the type of the defined `TESTAMENT`.
 #[proc_macro]
 pub fn git_testament(input: TokenStream) -> TokenStream {
-    let TestamentOptions { name } = parse_macro_input!(input as TestamentOptions);
+    let TestamentOptions { crate_, name } = parse_macro_input!(input);
 
     let InvocationInformation { pkgver, now } = InvocationInformation::acquire();
     let gitinfo = match GitInformation::acquire() {
@@ -354,9 +323,9 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
             );
             return (quote! {
                 #[allow(clippy::needless_update)]
-                static #name: git_testament::GitTestament<'static> = git_testament::GitTestament {
-                    commit: git_testament::CommitKind::NoRepository(#pkgver, #now),
-                    .. git_testament::EMPTY_TESTAMENT
+                const #name: #crate_::GitTestament<'static> = #crate_::GitTestament {
+                    commit: #crate_::CommitKind::NoRepository(#pkgver, #now),
+                    .. #crate_::EMPTY_TESTAMENT
                 };
             })
             .into();
@@ -366,9 +335,9 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
     // Second simple preliminary step: attempt to get a branch name to report
     let branch_name = {
         if let Some(branch) = gitinfo.branch {
-            quote! {Some(#branch)}
+            quote! {#crate_::__core::option::Option::Some(#branch)}
         } else {
-            quote! {None}
+            quote! {#crate_::__core::option::Option::None}
         }
     };
 
@@ -376,10 +345,10 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
     if gitinfo.commitinfo.is_none() {
         return (quote! {
             #[allow(clippy::needless_update)]
-            static #name: git_testament::GitTestament<'static> = git_testament::GitTestament {
-                commit: git_testament::CommitKind::NoCommit(#pkgver, #now),
+            const #name: #crate_::GitTestament<'static> = #crate_::GitTestament {
+                commit: #crate_::CommitKind::NoCommit(#pkgver, #now),
                 branch_name: #branch_name,
-                .. git_testament::EMPTY_TESTAMENT
+                .. #crate_::EMPTY_TESTAMENT
             };
         })
         .into();
@@ -396,12 +365,12 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
             commitinfo.distance,
         );
         quote! {
-            git_testament::CommitKind::FromTag(#tag, #id, #date, #distance)
+            #crate_::CommitKind::FromTag(#tag, #id, #date, #distance)
         }
     } else {
         let (id, date) = (&commitinfo.id, &commitinfo.date);
         quote! {
-            git_testament::CommitKind::NoTags(#id, #date)
+            #crate_::CommitKind::NoTags(#id, #date)
         }
     };
 
@@ -413,16 +382,16 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
             let path = status.path.clone().into_bytes();
             match status.status {
                 Untracked => quote! {
-                    git_testament::GitModification::Untracked(&[#(#path),*])
+                    #crate_::GitModification::Untracked(&[#(#path),*])
                 },
                 Added => quote! {
-                    git_testament::GitModification::Added(&[#(#path),*])
+                    #crate_::GitModification::Added(&[#(#path),*])
                 },
                 Modified => quote! {
-                    git_testament::GitModification::Modified(&[#(#path),*])
+                    #crate_::GitModification::Modified(&[#(#path),*])
                 },
                 Deleted => quote! {
-                    git_testament::GitModification::Removed(&[#(#path),*])
+                    #crate_::GitModification::Removed(&[#(#path),*])
                 },
             }
         })
@@ -430,89 +399,25 @@ pub fn git_testament(input: TokenStream) -> TokenStream {
 
     (quote! {
         #[allow(clippy::needless_update)]
-        static #name: git_testament::GitTestament<'static> = git_testament::GitTestament {
+        const #name: #crate_::GitTestament<'static> = #crate_::GitTestament {
             commit: #commit,
             modifications: &[#(#statuses),*],
             branch_name: #branch_name,
-            .. git_testament::EMPTY_TESTAMENT
+            .. #crate_::EMPTY_TESTAMENT
         };
     })
     .into()
 }
 
-// Clippy thinks our fn main() is needless, but it is needed because otherwise
-// we cannot have the invocation of the procedural macro (yet)
-#[allow(clippy::needless_doctest_main)]
-/// Generate a testament for the working tree as a set of static string macros.
-///
-/// This macro declares a set of macros which provide you with your testament
-/// as static strings.
-///
-/// The intention is that the macro should be used at the top level of a binary
-/// crate to provide information about the state of the codebase that the output
-/// program was built from.  This includes a number of things such as the commit
-/// SHA, any related tag, how many commits since the tag, the date of the commit,
-/// and if there are any "dirty" parts to the working tree such as modified files,
-/// uncommitted files, etc.
-///
-/// ```
-/// // Bring the procedural macro into scope
-/// use git_testament::git_testament_macros;
-///
-/// // Declare a testament, it'll end up as pile of macros, so you can
-/// // give it whatever ident-like name you want.  The name will prefix the
-/// // macro names.  Also you can optionally specify
-/// // a branch name which will be considered the "trusted" branch like in
-/// // `git_testament::render_testament!()`
-/// git_testament_macros!(version);
-/// # fn main() {
-///
-/// // ... later, you can display the testament.
-/// println!("app version {}", version_testament!());
-/// # }
-/// ```
-///
-/// The macros all resolve to string literals, boolean literals, or in the case
-/// of `NAME_tag_distance!()` a number.  This is most valuable when you are
-/// wanting to include the information into a compile-time-constructed string
-///
-/// ```
-/// // Bring the procedural macro into scope
-/// use git_testament::git_testament_macros;
-///
-/// // Declare a testament, it'll end up as pile of macros, so you can
-/// // give it whatever ident-like name you want.  The name will prefix the
-/// // macro names.  Also you can optionally specify
-/// // a branch name which will be considered the "trusted" branch like in
-/// // `git_testament::render_testament!()`
-/// git_testament_macros!(version, "stable");
-///
-/// const APP_VERSION: &str = concat!("app version ", version_testament!());
-/// # fn main() {
-///
-/// // ... later, you can display the testament.
-/// println!("{APP_VERSION}");
-/// # }
-/// ```
-///
-/// The set of macros defined is:
-///
-/// * `NAME_testament!()` -> produces a string similar but not guaranteed to be
-///   identical to the result of `Display` formatting a normal testament.
-/// * `NAME_branch!()` -> An Option<&str> of the current branch name
-/// * `NAME_repo_present!()` -> A boolean indicating if there is a repo at all
-/// * `NAME_commit_present!()` -> A boolean indicating if there is a commit present at all
-/// * `NAME_tag_present!()` -> A boolean indicating if there is a tag present
-/// * `NAME_commit_hash!()` -> A string of the commit hash (or crate version if commit not present)
-/// * `NAME_commit_date!()` -> A string of the commit date (or build date if no commit present)
-/// * `NAME_tag_name!()` -> The tag name if present (or crate version if commit not present)
-/// * `NAME_tag_distance!()` -> The number of commits since the tag if present (zero otherwise)
 #[proc_macro]
 pub fn git_testament_macros(input: TokenStream) -> TokenStream {
-    let StaticTestamentOptions { name, trusted } =
-        parse_macro_input!(input as StaticTestamentOptions);
+    let StaticTestamentOptions {
+        crate_,
+        name,
+        trusted,
+    } = parse_macro_input!(input);
     let sname = name.to_string();
-    let (pkgver, now, gitinfo, macros) = macro_content(&sname);
+    let (pkgver, now, gitinfo, macros) = macro_content(&crate_, &sname);
 
     // Render the testament string
     let testament = if let Some(gitinfo) = gitinfo {
@@ -521,7 +426,7 @@ pub fn git_testament_macros(input: TokenStream) -> TokenStream {
                 // No tag
                 format!("unknown ({} {})", &commitinfo.id[..9], commitinfo.date)
             } else {
-                let trusted = if gitinfo.branch == trusted {
+                let trusted = if gitinfo.branch == trusted.map(|v| v.value()) {
                     gitinfo.status.is_empty()
                 } else {
                     false
@@ -583,7 +488,10 @@ pub fn git_testament_macros(input: TokenStream) -> TokenStream {
     .into()
 }
 
-fn macro_content(prefix: &str) -> (String, String, Option<GitInformation>, impl quote::ToTokens) {
+fn macro_content(
+    crate_: &Ident,
+    prefix: &str,
+) -> (String, String, Option<GitInformation>, impl quote::ToTokens) {
     let InvocationInformation { pkgver, now } = InvocationInformation::acquire();
     let mac_branch = concat_ident(prefix, "branch");
     let mac_repo_present = concat_ident(prefix, "repo_present");
@@ -629,9 +537,9 @@ fn macro_content(prefix: &str) -> (String, String, Option<GitInformation>, impl
 
     let branch_name = {
         if let Some(ref branch) = gitinfo.branch {
-            quote! {Some(#branch)}
+            quote! {#crate_::__core::option::Option::Some(#branch)}
         } else {
-            quote! {None}
+            quote! {#crate_::__core::option::Option::None}
         }
     };
 
